@@ -8,6 +8,16 @@ end
 
 require "rubygems"
 require "rubygems/specification"
+
+begin
+  # Possible use in Gem::Specification#source below and require
+  # shouldn't be deferred.
+  require "rubygems/source"
+rescue LoadError
+  # Not available before Rubygems 2.0.0, ignore
+  nil
+end
+
 require "bundler/match_platform"
 
 module Gem
